/* cbs.h
 *
 * General routines for cubic b-splines.
 * 
 * History
 *  2011/06/24: First version
 *
 * Note
 *  CBS is partly based on the original source code of BBS.
 *
 * (c)2011, Florent Brunet.
 */
 
/* This file is part of CBS.
 *
 * CBS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * CBS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CBS.  If not, see <http://www.gnu.org/licenses/>.
 */
 
#ifndef __CBS_H__
#define __CBS_H__ 1

#include "matrix.h"

/* The B-Spline structure */
typedef struct _cbs_t {
    double tmin;
    double tmax;
    int npts;
    int valdim;
} cbs_t;

void normalize(double xmin, double xmax, int npts, double *x, int nb_x, double* nx);
void normalize_with_inter(double xmin, double xmax, int npts, double *x, int nb_x, double* nx, int *inter);

void eval_basis(double nx, double *val_basis);
void eval_basis_d(double nx, double *val_basis);
void eval_basis_dd(double nx, double *val_basis);

void eval(cbs_t *cbs, double *ctrlpts, double *t, int nval, double *val, int dt);

int coloc(cbs_t *cbs, double *t, int nsites, double *pr, mwIndex *ir, mwIndex *jc);
int coloc_deriv(cbs_t *cbs, double *t, int nsites, int dt, double *pr, mwIndex *ir, mwIndex *jc);

#endif
